#!/etc/opt/openit/perl -w
#
# Update olap-group-concurrency so it avoids unncessary 
# duplication of records for queued licenses. 
#
# Run in patch.cfg with
#
#   run:update_filter.pl
#

use strict;

my $cfg = "/var/opt/openit/etc/filtrator/olap-group-concurrency.conf";
my $old = "$cfg.old";
my $new = "$cfg.new";

# Only root can patch
if ( $< ne 0 ) {
    die "Error: Patching must be done as 'root'!\n";
}

open(IN, "$cfg") || die "Error: Unable to read old cfg '$cfg'!\n";

# Read in existing acc_types
my @lines = <IN>;
close(IN);

# Skip to definitions
my $ind = 0;
while($lines[$ind] !~ /filter-defs/ ) { 
	$ind++;
}

# Find Dupliate:records start
while($lines[$ind] !~ /Duplicate:records/ ) { 
    $ind++;
}

# Find global block
while($lines[$ind] !~ /global/ ) { 
	$ind++;
}

# Verify that fix isn't already applied
if ( $lines[$ind-1] =~ /limiting/) {
    print "Update already done, skipping\n";
    exit 0;
}

# Add new line
splice(@lines, $ind, 0,
	   "\t\t\tlimiting(String)=\"queued_licenses > 0\"\{\}\n");
 

# Write new file
open(OUT, ">$new") || die "Error: Can't write new cfg '$new'!\n";
print OUT @lines;
close(OUT);

if( ! rename($cfg, $old)) {
    die "Error: Unable to previous config to '$old'!\n";
}

if( ! rename($new, $cfg)) {
    die "Error: Unable to rename new config to '$cfg'!\n";
}

exit 0;
